@@ -773,11 +773,9 @@ void MyMoneyFile::removeAccountList(const QStringList& account_list, unsigned in
 
   // upon entry, we check that we could proceed with the operation
   if (!level) {
-    if (!hasOnlyUnusedAccounts(account_list, 0))
+    if (!hasOnlyUnusedAccounts(account_list, 0)) {
       throw new MYMONEYEXCEPTION("One or more accounts cannot be removed");
-
-    // NOTE: We don't use a MyMoneyNotifier here, but rather clear the whole cache
-    d->m_cache.clear();
+    }
   }
 
   // process all accounts in the list and test if they have transactions assigned
@@ -794,6 +792,9 @@ void MyMoneyFile::removeAccountList(const QStringList& account_list, unsigned in
       // the MyMoneyAccount object. Easiest way is to get a fresh copy.
       a = d->m_storage->account(*it);
     }
+
+    // make sure to remove the item from the cache
+    d->m_cache.clear(a.id());
     removeAccount(a);
   }
 }
@@ -2183,6 +2184,34 @@ const QStringList MyMoneyFile::consistencyCheck(void)
     }
   }
 
+  // Fix the budgets that somehow still reference invalid accounts
+  QString problemBudget;
+  QList<MyMoneyBudget> bList = budgetList();
+  for (QList<MyMoneyBudget>::const_iterator it_b = bList.constBegin(); it_b != bList.constEnd(); ++it_b) {
+    MyMoneyBudget b = *it_b;
+    QList<MyMoneyBudget::AccountGroup> baccounts = b.getaccounts();
+    bool bChanged = false;
+    for (QList<MyMoneyBudget::AccountGroup>::const_iterator it_bacc = baccounts.constBegin(); it_bacc != baccounts.constEnd(); ++it_bacc) {
+      try {
+        account((*it_bacc).id());
+      } catch (MyMoneyException *e) {
+        problemCount++;
+        if (problemBudget != b.name()) {
+          problemBudget = b.name();
+          rc << i18n("* Problem with budget '%1'", problemBudget);
+        }
+        rc << i18n("  * The account with id %1 referenced by the budget does not exist anymore.", (*it_bacc).id());
+        rc << i18n("    The account reference will be removed.");
+        // remove the reference to the account
+        b.removeReference((*it_bacc).id());
+        bChanged = true;
+      }
+    }
+    if (bChanged) {
+      d->m_storage->modifyBudget(b);
+    }
+  }
+
   // add more checks here
 
   if (problemCount == 0 && unfixedCount == 0) {
@@ -2758,6 +2787,23 @@ QString MyMoneyFile::storageId(void)
   return id;
 }
 
+bool MyMoneyFile::hasMatchingOnlineBalance(const MyMoneyAccount& _acc) const
+{
+  // get current values
+  MyMoneyAccount acc = account(_acc.id());
+
+  // if there's no last transaction import data we are done
+  if( acc.value("lastImportedTransactionDate").isEmpty()
+      || acc.value("lastStatementBalance").isEmpty())
+    return false;
+
+  // otherwise, we compare the balances
+  MyMoneyMoney balance(acc.value("lastStatementBalance"));
+  MyMoneyMoney accBalance = this->balance(acc.id(), QDate::fromString(acc.value("lastImportedTransactionDate"), Qt::ISODate));
+
+  return balance == accBalance;
+}
+
 MyMoneyFileTransaction::MyMoneyFileTransaction() :
     m_isNested(MyMoneyFile::instance()->hasTransaction()),
     m_needRollback(!m_isNested)
