@@ -58,6 +58,7 @@
 #include "stdtransactionmatched.h"
 #include "scheduledtransaction.h"
 #include "kmymoneyglobalsettings.h"
+#include "mymoneyfile.h"
 
 const int LinesPerMemo = 3;
 
@@ -234,7 +235,8 @@ bool ItemPtrVector::item_cmp(RegisterItem* i1, RegisterItem* i2)
 GroupMarker::GroupMarker(Register *parent, const QString& txt) :
     RegisterItem(parent),
     m_txt(txt),
-    m_showDate(false)
+    m_showDate(false),
+    m_erroneous(false)
 {
   int h;
   if (m_parent) {
@@ -284,7 +286,7 @@ void GroupMarker::paintRegisterCell(QPainter *painter, QStyleOptionViewItemV4 &o
   cellRect.setWidth(m_parent->viewport()->width());
   cellRect.setHeight(m_parent->rowHeight(index.row()));
 
-  option.palette.setColor(QPalette::Base, KMyMoneyGlobalSettings::groupMarkerColor());
+  option.palette.setColor(QPalette::Base, isErronous() ? KMyMoneyGlobalSettings::listErronousTransactionColor() : KMyMoneyGlobalSettings::groupMarkerColor());
 
   QBrush backgroundBrush(option.palette.color(QPalette::Base));
   painter->fillRect(cellRect, backgroundBrush);
@@ -292,7 +294,7 @@ void GroupMarker::paintRegisterCell(QPainter *painter, QStyleOptionViewItemV4 &o
   painter->drawLine(cellRect.x(), cellRect.height() - 1, cellRect.width(), cellRect.height() - 1);
 
   // now write the text
-  painter->setPen(option.palette.color(QPalette::Text));
+  painter->setPen(option.palette.color( isErronous() ? QPalette::HighlightedText : QPalette::Text ));
   QFont font = painter->font();
   font.setBold(true);
   painter->setFont(font);
@@ -1018,7 +1020,6 @@ void Register::focusInEvent(QFocusEvent* ev)
   QTableWidget::focusInEvent(ev);
   if (m_focusItem) {
     m_focusItem->setFocus(true, false);
-    repaintItems(m_focusItem);
   }
 }
 
@@ -1061,7 +1062,6 @@ void Register::focusOutEvent(QFocusEvent* ev)
 {
   if (m_focusItem) {
     m_focusItem->setFocus(false, false);
-    repaintItems(m_focusItem);
   }
   QTableWidget::focusOutEvent(ev);
 }
@@ -1267,25 +1267,10 @@ void Register::adjustColumn(int col)
 #endif
 }
 
-void Register::repaintItems(RegisterItem* first, RegisterItem* last)
-{
-  if (first == 0 && last == 0) {
-    first = firstItem();
-    last = lastItem();
-  }
-
-  if (first == 0)
-    return;
-
-  if (last == 0)
-    last = first;
-
-  // TODO: port the register - trigger a repaint
-}
-
 void Register::clearSelection(void)
 {
   unselectItems();
+  TransactionEditorContainer::clearSelection();
 }
 
 void Register::doSelectItems(int from, int to, bool selected)
@@ -1319,10 +1304,6 @@ void Register::doSelectItems(int from, int to, bool selected)
       }
     }
   }
-
-  // anything changed?
-  if (firstItem || lastItem)
-    repaintItems(firstItem, lastItem);
 }
 
 RegisterItem* Register::itemAtRow(int row) const
@@ -1466,9 +1447,6 @@ bool Register::setFocusItem(RegisterItem* focusItem)
   if (focusItem && focusItem->canHaveFocus()) {
     if (m_focusItem) {
       m_focusItem->setFocus(false);
-      // issue a repaint here only if we move the focus
-      if (m_focusItem != focusItem)
-        repaintItems(m_focusItem);
     }
     Transaction* item = dynamic_cast<Transaction*>(focusItem);
     if (m_focusItem != focusItem && item) {
@@ -1480,7 +1458,6 @@ bool Register::setFocusItem(RegisterItem* focusItem)
     if (m_listsDirty)
       updateRegister(KMyMoneyGlobalSettings::ledgerLens() | !KMyMoneyGlobalSettings::transactionForm());
     ensureItemVisible(m_focusItem);
-    repaintItems(m_focusItem);
     return true;
   } else
     return false;
@@ -1632,8 +1609,9 @@ void Register::slotEnsureItemVisible(void)
   setUpdatesEnabled(false);
   updateRegister();
   setUpdatesEnabled(true);
-  scrollTo(model()->index(m_ensureVisibleItem->startRow(), DetailColumn));
+  // since the item will be made visible at the top of the viewport make the bottom index visible first to make the whole item visible
   scrollTo(model()->index(m_ensureVisibleItem->startRow() + m_ensureVisibleItem->numRowsRegister() - 1, DetailColumn));
+  scrollTo(model()->index(m_ensureVisibleItem->startRow(), DetailColumn));
 }
 
 TransactionSortField KMyMoneyRegister::textToSortOrder(const QString& text)
@@ -1912,6 +1890,12 @@ void Register::keyPressEvent(QKeyEvent* ev)
     case Qt::Key_Up:
       scrollPage(ev->key(), ev->modifiers());
       break;
+    case Qt::Key_Enter:
+    case Qt::Key_Return:
+      // don't emit the signal right away but wait until
+      // we come back to the Qt main loop
+      QTimer::singleShot(0, this, SIGNAL(editTransaction()));
+      break;
 
     default:
       QTableWidget::keyPressEvent(ev);
@@ -2013,7 +1997,10 @@ void Register::addGroupMarkers(void)
           if (m_account.accountGroup() == MyMoneyAccount::Liability)
             balance = -balance;
           QString txt = i18n("Online Statement Balance: %1", balance.formatMoney(m_account.fraction()));
-          new KMyMoneyRegister::StatementGroupMarker(this, KMyMoneyRegister::Deposit, QDate::fromString(m_account.value("lastImportedTransactionDate"), Qt::ISODate), txt);
+
+          KMyMoneyRegister::StatementGroupMarker *p=new KMyMoneyRegister::StatementGroupMarker(this, KMyMoneyRegister::Deposit, QDate::fromString(m_account.value("lastImportedTransactionDate"), Qt::ISODate), txt);
+
+          p->setErroneous(!MyMoneyFile::instance()->hasMatchingOnlineBalance(m_account));
         }
 
         new KMyMoneyRegister::FancyDateGroupMarker(this, thisYear, i18n("This year"));
